<div id="top"></div>
<p align="center">
  <img src="https://img.shields.io/github/contributors/dropout1337/Discord-iOS.svg?style=for-the-badge"/>
  <img src="https://img.shields.io/github/forks/dropout1337/Discord-iOS.svg?style=for-the-badge"/>
  <img src="https://img.shields.io/github/stars/dropout1337/Discord-iOS.svg?style=for-the-badge"/>
  <img src="https://img.shields.io/github/issues/dropout1337/Discord-iOS.svg?style=for-the-badge"/>
  <img src="https://img.shields.io/github/license/dropout1337/Discord-iOS.svg?style=for-the-badge"/>
</p>
  
---------------------------------------
  
<br/>
<div align="center">
  <a href="https://github.com/dropout1337/Discord-iOS">
    <img src="https://discord.com/assets/9f6f9cd156ce35e2d94c0e62e3eff462.png" alt="Logo" width="120" height="120">
  </a>
  
  <h2 align="center">Discord-iOS</h3>

  <p align="center">
    Make your bot appear on mobile.
    <br />
    <br />
    <a href="https://github.com/dropout1337/Discord-iOS/issues">Report Bug</a>
    ·
    <a href="https://github.com/dropout1337/Discord-iOS/issues">Request Feature</a>
  </p>
</div>

---------------------------------------

```
pip install -U git+https://github.com/dropout1337/Discord-iOS/
```

```py
import discord_ios

import discord
from discord.ext import commands

client = commands.Bot(...)
```
- All you need todo is import `discord_ios` before any discord.py related librarys.

### Contact
View my contact information on my [telegram](https://t.me/dropoutuwu/)
